@@ -10,13 +10,13 @@ import sys
 
 app_name = get_app_name()
 args = get_args()
-print('test-2')
+args.remove(app_name)
 
 def main():
-    print('test-3')
     if (is_name_valid(app_name)):
-
         # validate all arguments first!!
+        validate_args(args)
+
         if(is_args_valid(args)):
             
             print(';;;;;;;;;;')
