@@ -32,11 +32,13 @@ def get_args():
   return args
 
 def is_args_valid(args):
-  print(args)
-  args.pop(1)
   valid_args =  all(arg in valid_args_list for arg in args)
   return valid_args
 
+def validate_args(args):
+  print(args)
+  print('test')
+
 # create directory for application
 def create_dir(app_name):
   try:
